pymodaq_plugins_hinds
#####################

.. the following must be adapted to your developed package, links to pypi, github  description...

.. image:: https://img.shields.io/pypi/v/pymodaq_plugins_hinds.svg
   :target: https://pypi.org/project/pymodaq_plugins_hinds/
   :alt: Latest Version

.. image:: https://readthedocs.org/projects/pymodaq/badge/?version=latest
   :target: https://pymodaq.readthedocs.io/en/stable/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/NanoQM/pymodaq_plugins_hinds/workflows/Upload%20Python%20Package/badge.svg
   :target: https://github.com/NanoQM/pymodaq_plugins_hinds
   :alt: Publication Status

.. image:: https://github.com/NanoQM/pymodaq_plugins_hinds/actions/workflows/Test.yml/badge.svg
    :target: https://github.com/NanoQM/pymodaq_plugins_hinds/actions/workflows/Test.yml


Hinds instruments controller for Photoelastic Modulator-200.

Authors
=======

* Astha Khandelwal (asthak@iisc.ac.in)
* Daichi Kozawa (KOZAWA.Daichi@nims.go.jp)

.. if needed use this field

    Contributors
    ============

    * First Contributor
    * Other Contributors

 .. if needed use this field

  Depending on the plugin type, delete/complete the fields below


Instruments
===========

Below is the list of instruments included in this plugin

Actuators
=========

* **PEM 200**: controller for the Photoelastic modulator

.. Viewer0D
.. ++++++++

.. * **yyy**: control of yyy 0D detector
.. * **xxx**: control of xxx 0D detector



..  Viewer1D
.. ++++++++

.. * **yyy**: control of yyy 1D detector
.. * **xxx**: control of xxx 1D detector


..  Viewer2D
.. ++++++++

.. * **yyy**: control of yyy 2D detector
..  * **xxx**: control of xxx 2D detector

Installation instructions
=========================

* Tested with PyMoDAQ’s version: 4.4.7
* PEM200 User Interface

    install through hinds's instrument website https://www.hindsinstruments.com/products/components/photoelastic-modulators/pem-200-controller/